@@ -40,7 +40,7 @@ class GetCapabilitiesAction(base.TripleOAction):
 
     def run(self):
         try:
-            swift_client = self._get_object_client()
+            swift_client = self.get_object_client()
             map_file = swift_client.get_object(
                 self.container, 'capabilities-map.yaml')
             capabilities = yaml.safe_load(map_file[1])
@@ -48,10 +48,7 @@ class GetCapabilitiesAction(base.TripleOAction):
             err_msg = (
                 "Error parsing capabilities-map.yaml.")
             LOG.exception(err_msg)
-            return mistral_workflow_utils.Result(
-                None,
-                err_msg
-            )
+            return mistral_workflow_utils.Result(error=err_msg)
         try:
             container_files = swift_client.get_container(self.container)
             container_file_list = [entry['name'] for entry
@@ -59,21 +56,15 @@ class GetCapabilitiesAction(base.TripleOAction):
         except Exception as swift_err:
             err_msg = ("Error retrieving plan files: %s" % swift_err)
             LOG.exception(err_msg)
-            return mistral_workflow_utils.Result(
-                None,
-                err_msg
-            )
+            return mistral_workflow_utils.Result(error=err_msg)
         try:
-            mistral_client = self._get_workflow_client()
+            mistral_client = self.get_workflow_client()
             mistral_env = mistral_client.environments.get(self.container)
         except Exception as mistral_err:
             err_msg = ("Error retrieving mistral "
                        "environment. %s" % mistral_err)
             LOG.exception(err_msg)
-            return mistral_workflow_utils.Result(
-                None,
-                err_msg
-            )
+            return mistral_workflow_utils.Result(error=err_msg)
 
         selected_envs = [item['path'] for item in
                          mistral_env.variables['environments']
@@ -166,7 +157,7 @@ class UpdateCapabilitiesAction(base.TripleOAction):
         self.environments = environments
 
     def run(self):
-        mistral_client = self._get_workflow_client()
+        mistral_client = self.get_workflow_client()
         mistral_env = None
         try:
             mistral_env = mistral_client.environments.get(self.container)
@@ -175,10 +166,7 @@ class UpdateCapabilitiesAction(base.TripleOAction):
                 "Error retrieving mistral "
                 "environment. %s" % mistral_err)
             LOG.exception(err_msg)
-            return mistral_workflow_utils.Result(
-                None,
-                err_msg
-            )
+            return mistral_workflow_utils.Result(error=err_msg)
 
         for k, v in self.environments.items():
             found = False
@@ -203,8 +191,5 @@ class UpdateCapabilitiesAction(base.TripleOAction):
             err_msg = (
                 "Error retrieving mistral environment. %s" % mistral_err)
             LOG.exception(err_msg)
-            return mistral_workflow_utils.Result(
-                None,
-                err_msg
-            )
+            return mistral_workflow_utils.Result(error=err_msg)
         return mistral_env.variables
