@@ -31,7 +31,7 @@ class SwiftTempUrlAction(base.TripleOAction):
         self.valid = valid
 
     def run(self):
-        swift_client = self._get_object_client()
+        swift_client = self.get_object_client()
 
         try:
             cont_stat = swift_client.head_container(self.container)
